==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/fe-deploy/deploy-config-manager.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React from 'react';
import { Loading, ShowModal, CloseGlobalModal, TipPanel, FormLayout } from 'ukelli-ui';
import ActionAgent from "../action-agent";
import { getSShConfig, addSShConfig, updateSShConfig, delSShConfig } from './apis';
import RecordRender from '../template-engine/for-report/records-template';
import WrapDeployForms from './deploy-forms';
var ConfigFac = function (api, title) { return /** @class */ (function (_super) {
    __extends(C, _super);
    function C() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = __assign(__assign({}, _this.state), { ready: false, formOptions: [] });
        _this.formBtns = [
            {
                text: title,
                actingRef: 'adding',
                action: function (formRef, actingRef) {
                    var isSuccess = _this.reqAgent(api, {
                        actingRef: actingRef
                    })(formRef.value);
                    if (isSuccess)
                        _this.props.onSuccessed();
                }
            }
        ];
        return _this;
    }
    C.prototype.componentDidMount = function () {
        this.getFormOptions();
    };
    C.prototype.getFormOptions = function () {
        return __awaiter(this, void 0, void 0, function () {
            var formOptions;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, WrapDeployForms(this.props.target)];
                    case 1:
                        formOptions = _a.sent();
                        this.setState({
                            formOptions: formOptions,
                            ready: true,
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    C.prototype.render = function () {
        var _a = this.state, ready = _a.ready, formOptions = _a.formOptions;
        return (React.createElement(Loading, { loading: !ready },
            React.createElement(FormLayout, { formBtns: this.formBtns, formOptions: formOptions })));
    };
    return C;
}(ActionAgent)); };
var EditConfig = ConfigFac(updateSShConfig, '编辑');
var AddConfig = ConfigFac(addSShConfig, '新增');
var DeployConfigManager = /** @class */ (function (_super) {
    __extends(DeployConfigManager, _super);
    function DeployConfigManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = __assign(__assign({}, _this.state), { records: [], querying: true });
        _this.columns = [
            {
                key: 'sshHost',
                title: 'SSH Host',
            },
            // {
            //   key: 'alias',
            //   title: '别名',
            // },
            {
                key: 'deployPath',
                title: '部署路径',
            },
            {
                key: 'desc',
                title: '用途',
            },
            {
                key: 'action',
                title: '操作',
                filter: function (_, item) {
                    return (React.createElement(React.Fragment, null,
                        React.createElement("span", { className: "link-btn mr10", onClick: function (e) {
                                var ModalId = ShowModal({
                                    showFuncBtn: false,
                                    title: '编辑',
                                    children: (React.createElement(EditConfig, { target: item, onSuccessed: function (e) {
                                            _this.queryData();
                                            CloseGlobalModal(ModalId);
                                        } }))
                                });
                            } }, "\u7F16\u8F91"),
                        React.createElement("span", { className: "link-btn", onClick: function (e) {
                                var ModalId = ShowModal({
                                    title: '删除',
                                    type: 'confirm',
                                    width: 300,
                                    confirmText: '确定删除？',
                                    onConfirm: function (isSure) { return __awaiter(_this, void 0, void 0, function () {
                                        var err;
                                        return __generator(this, function (_a) {
                                            switch (_a.label) {
                                                case 0:
                                                    if (!isSure)
                                                        return [2 /*return*/];
                                                    return [4 /*yield*/, delSShConfig(item)];
                                                case 1:
                                                    err = (_a.sent()).err;
                                                    !err && CloseGlobalModal(ModalId);
                                                    this.queryData();
                                                    return [2 /*return*/];
                                            }
                                        });
                                    }); }
                                });
                            } }, "\u5220\u9664")));
                }
            },
        ];
        _this.actionsBtns = [
            {
                action: function () {
                    var ModalId = ShowModal({
                        showFuncBtn: false,
                        title: '新增配置',
                        children: (React.createElement(AddConfig, { onSuccessed: function (e) {
                                _this.queryData();
                                CloseGlobalModal(ModalId);
                            } }))
                    });
                },
                text: '新增配置',
                color: 'green'
            }
        ];
        _this.queryData = function () {
            _this.reqAgent(getSShConfig, {
                actingRef: 'querying',
                after: function (resData) {
                    return {
                        records: resData.data || []
                    };
                }
            })();
        };
        return _this;
    }
    // componentDidMount() {
    //   this.queryData();
    // }
    DeployConfigManager.prototype.render = function () {
        var _a = this.state, querying = _a.querying, records = _a.records;
        return (React.createElement("div", { className: "card-content" },
            React.createElement(TipPanel, { title: "\u4F7F\u7528\u8BF4\u660E", needToolTip: true, n: "angle-up", defaultShow: false, texts: [
                    '为了更好的管理发布机器和部署路径',
                    '统一在 ~/.ssh/config 中配置',
                    '系统会分析 Host 后面第一个注释 #xx 作为 ssh 描述',
                    '将会在新增前端资源时使用该配置',
                ] }),
            React.createElement(RecordRender, { height: "60vh", onQueryData: this.queryData, querying: querying, actionBtns: this.actionsBtns, hideFloatable: true, columns: this.columns, records: records })));
    };
    return DeployConfigManager;
}(ActionAgent));
export default DeployConfigManager;

==> uke-admin-web-scaffold-1.2.4.tgz: package/fe-deploy/deploy-config-manager.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React from 'react';
import { Loading, ShowModal, CloseGlobalModal, Alert, FormLayout } from 'ukelli-ui';
import ActionAgent from "../action-agent";
import { getSShConfig, addSShConfig, updateSShConfig, delSShConfig } from './apis';
import RecordRender from '../template-engine/for-report/records-template';
import WrapDeployForms from './deploy-forms';
var ConfigFac = function (api, title) { return /** @class */ (function (_super) {
    __extends(C, _super);
    function C() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = __assign(__assign({}, _this.state), { ready: false, formOptions: [] });
        _this.formBtns = [
            {
                text: title,
                actingRef: 'adding',
                action: function (formRef, actingRef) {
                    var isSuccess = _this.reqAgent(api, {
                        actingRef: actingRef
                    })(formRef.value);
                    if (isSuccess)
                        _this.props.onSuccessed();
                }
            }
        ];
        return _this;
    }
    C.prototype.componentDidMount = function () {
        this.getFormOptions();
    };
    C.prototype.getFormOptions = function () {
        return __awaiter(this, void 0, void 0, function () {
            var formOptions;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, WrapDeployForms(this.props.target)];
                    case 1:
                        formOptions = _a.sent();
                        this.setState({
                            formOptions: formOptions,
                            ready: true,
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    C.prototype.render = function () {
        var _a = this.state, ready = _a.ready, formOptions = _a.formOptions;
        return (React.createElement(Loading, { loading: !ready },
            React.createElement(FormLayout, { formBtns: this.formBtns, formOptions: formOptions })));
    };
    return C;
}(ActionAgent)); };
var EditConfig = ConfigFac(updateSShConfig, '编辑');
var AddConfig = ConfigFac(addSShConfig, '新增');
var DeployConfigManager = /** @class */ (function (_super) {
    __extends(DeployConfigManager, _super);
    function DeployConfigManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = __assign(__assign({}, _this.state), { records: [], querying: true });
        _this.columns = [
            {
                key: 'sshHost',
                title: 'SSH Host',
            },
            // {
            //   key: 'alias',
            //   title: '别名',
            // },
            {
                key: 'deployPath',
                title: '部署路径',
            },
            {
                key: 'desc',
                title: '用途',
            },
            {
                key: 'action',
                title: '操作',
                filter: function (_, item) {
                    return (React.createElement(React.Fragment, null,
                        React.createElement("span", { className: "link-btn mr10", onClick: function (e) {
                                var ModalId = ShowModal({
                                    showFuncBtn: false,
                                    title: '编辑',
                                    children: (React.createElement(EditConfig, { target: item, onSuccessed: function (e) {
                                            _this.queryData();
                                            CloseGlobalModal(ModalId);
                                        } }))
                                });
                            } }, "\u7F16\u8F91"),
                        React.createElement("span", { className: "link-btn", onClick: function (e) {
                                var ModalId = ShowModal({
                                    title: '删除',
                                    type: 'confirm',
                                    width: 300,
                                    confirmText: '确定删除？',
                                    onConfirm: function (isSure) { return __awaiter(_this, void 0, void 0, function () {
                                        var err;
                                        return __generator(this, function (_a) {
                                            switch (_a.label) {
                                                case 0:
                                                    if (!isSure)
                                                        return [2 /*return*/];
                                                    return [4 /*yield*/, delSShConfig(item)];
                                                case 1:
                                                    err = (_a.sent()).err;
                                                    !err && CloseGlobalModal(ModalId);
                                                    this.queryData();
                                                    return [2 /*return*/];
                                            }
                                        });
                                    }); }
                                });
                            } }, "\u5220\u9664")));
                }
            },
        ];
        _this.actionsBtns = [
            {
                action: function () {
                    var ModalId = ShowModal({
                        showFuncBtn: false,
                        title: '新增配置',
                        children: (React.createElement(AddConfig, { onSuccessed: function (e) {
                                _this.queryData();
                                CloseGlobalModal(ModalId);
                            } }))
                    });
                },
                text: '新增配置',
                color: 'green'
            }
        ];
        _this.queryData = function () {
            _this.reqAgent(getSShConfig, {
                actingRef: 'querying',
                after: function (resData) {
                    return {
                        records: resData.data || []
                    };
                }
            })();
        };
        return _this;
    }
    // componentDidMount() {
    //   this.queryData();
    // }
    DeployConfigManager.prototype.render = function () {
        var _a = this.state, querying = _a.querying, records = _a.records;
        return (React.createElement("div", { className: "card-content" },
            React.createElement(Alert, { title: "\u4F7F\u7528\u8BF4\u660E", needToolTip: true, n: "angle-up", defaultShow: false, texts: [
                    '为了更好的管理发布机器和部署路径',
                    '统一在 ~/.ssh/config 中配置',
                    '系统会分析 Host 后面第一个注释 #xx 作为 ssh 描述',
                    '将会在新增前端资源时使用该配置',
                ] }),
            React.createElement(RecordRender, { height: "60vh", onQueryData: this.queryData, querying: querying, actionBtns: this.actionsBtns, hideFloatable: true, columns: this.columns, records: records })));
    };
    return DeployConfigManager;
}(ActionAgent));
export default DeployConfigManager;
